@@ -15,10 +15,11 @@
 #   limitations under the License
 #
 __author__ = 'Ohad Mata <ohadmata@gmail.com>'
-__version__ = '0.0.2'
+__version__ = '0.0.5'
 
 from flask import Blueprint
 from airflow.plugins_manager import AirflowPlugin
+from airflow import configuration
 from simple_dag_editor.commons import STATIC
 from simple_dag_editor.flask_admin_view import admin_view
 
@@ -32,12 +33,23 @@ simple_dag_editor_blueprint = Blueprint(
     static_url_path=STATIC,
 )
 
+
 class DagEditorPlugin(AirflowPlugin):
-    name = 'simple_dag_editor'
-    operators = []
-    flask_blueprints = [simple_dag_editor_blueprint]
-    hooks = []
-    executors = []
-    admin_views = [admin_view] if admin_view is not None else []
-    menu_links = []
-    appbuilder_views = []
+    if configuration.getboolean('dag_editor', 'DISABLED', fallback=False):
+        name = 'simple_dag_editor'
+        operators = []
+        flask_blueprints = []
+        hooks = []
+        executors = []
+        admin_views = []
+        menu_links = []
+        appbuilder_views = []
+    else:
+        name = 'simple_dag_editor'
+        operators = []
+        flask_blueprints = [simple_dag_editor_blueprint]
+        hooks = []
+        executors = []
+        admin_views = [admin_view] if admin_view is not None else []
+        menu_links = []
+        appbuilder_views = []
